.. _all-salt.states:

=============
state modules
=============

.. currentmodule:: salt.states

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    alias
    ansiblegate
    apache
    apache_conf
    apache_module
    apache_site
    archive
    at
    beacon
    blockdev
    chocolatey
    cloud
    cmd
    cron
    disk
    environ
    etcd_mod
    event
    file
    firewall
    firewalld
    git
    gpg
    grains
    group
    highstate_doc
    host
    http
    idem
    ini_manage
    ipset
    iptables
    keyboard
    kmod
    linux_acl
    locale
    logrotate
    loop
    lvm
    mac_assistive
    mac_keychain
    mac_xattr
    macdefaults
    macpackage
    makeconf
    mdadm_raid
    module
    mount
    netacl
    netconfig
    netntp
    netsnmp
    netusers
    network
    nftables
    ntp
    pip_state
    pkg
    pkgbuild
    pkgng
    pkgrepo
    postgres_cluster
    postgres_database
    postgres_extension
    postgres_group
    postgres_initdb
    postgres_language
    postgres_privileges
    postgres_schema
    postgres_tablespace
    postgres_user
    process
    proxy
    pyenv
    quota
    rabbitmq_cluster
    rabbitmq_plugin
    rabbitmq_policy
    rabbitmq_upstream
    rabbitmq_user
    rabbitmq_vhost
    reg
    salt_proxy
    saltmod
    saltutil
    schedule
    selinux
    service
    ssh_auth
    ssh_known_hosts
    ssh_pki
    stateconf
    status
    sysctl
    sysfs
    syslog_ng
    test
    timezone
    tls
    uptime
    user
    virtualenv_mod
    win_appx
    win_certutil
    win_dacl
    win_dism
    win_dns_client
    win_firewall
    win_iis
    win_lgpo
    win_lgpo_reg
    win_license
    win_network
    win_path
    win_pki
    win_powercfg
    win_servermanager
    win_shortcut
    win_smtp_server
    win_snmp
    win_system
    win_task
    win_wua
    win_wusa
    winrepo
    x509
    x509_v2
